@@ -1,10 +1,11 @@
 # ABSTRACT: Fix version issues to support all the things
 package App::ElasticSearch::Utilities::VersionHacks;
 
-our $VERSION = '5.4'; # VERSION
 use strict;
 use warnings;
 
+our $VERSION = '5.5'; # VERSION
+
 use Const::Fast;
 use CLI::Helpers qw(:all);
 use Sub::Exporter -setup => {
@@ -127,7 +128,7 @@ sub _cluster_state_1_0 {
         my @requested = ();
         if( exists $options->{uri_param} ) {
             my %filters =
-                    map { s/filter_//; $_ => 1; }
+                    map  { /filter_(.+)$/; $1 => 1 }
                     grep { /^filter_/ && $options->{uri_param}{$_} }
                 keys %{ $options->{uri_param} };
             # Remove them from the parameters
@@ -163,7 +164,7 @@ App::ElasticSearch::Utilities::VersionHacks - Fix version issues to support all
 
 =head1 VERSION
 
-version 5.4
+version 5.5
 
 =head1 AUTHOR
 
